===========
FieldReport
===========

Field report commands are used to write a field output report and free body computational results to an ASCII file.


Create field reports in Session
-------------------------------

.. autoclass:: abaqus.FieldReport.FieldReportSession.FieldReportSession
    :members:
    

Object features
---------------

FieldReportOptions
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.FieldReport.FieldReportOptions.FieldReportOptions
    :members:

    .. autoclasstoc::

FreeBodyReportOptions
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.FieldReport.FreeBodyReportOptions.FreeBodyReportOptions
    :members:

    .. autoclasstoc::

OdbFieldVarList
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.FieldReport.OdbFieldVarList.OdbFieldVarList
    :members:

    .. autoclasstoc::

OdbModelFieldVarList
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.FieldReport.OdbModelFieldVarList.OdbModelFieldVarList
    :members:

    .. autoclasstoc::

writeFieldReport
~~~~~~~~~~~~~~~~

.. automodule:: abaqus.FieldReport.writeFieldReport
    :members:

writeFreeBodyReport
~~~~~~~~~~~~~~~~~~~

.. automodule:: abaqus.FieldReport.writeFreeBodyReport
    :members:
